==> chaosmesh-model-5.2.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/TimeChaosListBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class TimeChaosListBuilder extends TimeChaosListFluentImpl<TimeChaosListBuilder> implements VisitableBuilder<TimeChaosList,TimeChaosListBuilder> {

    TimeChaosListFluent<?> fluent;
    Boolean validationEnabled;

    public TimeChaosListBuilder() {
        this(true);
    }

    public TimeChaosListBuilder(Boolean validationEnabled) {
        this(new TimeChaosList(), validationEnabled);
    }

    public TimeChaosListBuilder(TimeChaosListFluent<?> fluent) {
        this(fluent, true);
    }

    public TimeChaosListBuilder(TimeChaosListFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new TimeChaosList(), validationEnabled);
    }

    public TimeChaosListBuilder(TimeChaosListFluent<?> fluent,TimeChaosList instance) {
        this(fluent, instance, true);
    }

    public TimeChaosListBuilder(TimeChaosListFluent<?> fluent,TimeChaosList instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public TimeChaosListBuilder(TimeChaosList instance) {
        this(instance,true);
    }

    public TimeChaosListBuilder(TimeChaosList instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditableTimeChaosList build() {
        EditableTimeChaosList buildable = new EditableTimeChaosList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        TimeChaosListBuilder that = (TimeChaosListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> chaosmesh-model-5.3.2-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/TimeChaosListBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class TimeChaosListBuilder extends TimeChaosListFluentImpl<TimeChaosListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<TimeChaosList,TimeChaosListBuilder> {

    TimeChaosListFluent<?> fluent;
    Boolean validationEnabled;

    public TimeChaosListBuilder() {
        this(true);
    }

    public TimeChaosListBuilder(Boolean validationEnabled) {
        this(new TimeChaosList(), validationEnabled);
    }

    public TimeChaosListBuilder(TimeChaosListFluent<?> fluent) {
        this(fluent, true);
    }

    public TimeChaosListBuilder(TimeChaosListFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new TimeChaosList(), validationEnabled);
    }

    public TimeChaosListBuilder(TimeChaosListFluent<?> fluent,TimeChaosList instance) {
        this(fluent, instance, true);
    }

    public TimeChaosListBuilder(TimeChaosListFluent<?> fluent,TimeChaosList instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public TimeChaosListBuilder(TimeChaosList instance) {
        this(instance,true);
    }

    public TimeChaosListBuilder(TimeChaosList instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditableTimeChaosList build() {
        EditableTimeChaosList buildable = new EditableTimeChaosList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        TimeChaosListBuilder that = (TimeChaosListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
